@@ -6,19 +6,22 @@ from .leafexpr import LeafExpr
 from .addr import Addr
 from .bytes import Bytes
 from .int import Int, EnumInt
+from .methodsig import MethodSignature
 
 # properties
 from .arg import Arg
 from .txn import TxnType, TxnField, TxnExpr, TxnaExpr, TxnArray, TxnObject, Txn
 from .gtxn import GtxnExpr, GtxnaExpr, TxnGroup, Gtxn
 from .gaid import GeneratedID
+from .gitxn import Gitxn, GitxnExpr, GitxnaExpr, InnerTxnGroup
 from .gload import ImportScratchValue
 from .global_ import Global, GlobalField
 from .app import App, AppField, OnComplete, AppParam
 from .asset import AssetHolding, AssetParam
+from .acct import AccountParam
 
 # inner txns
-from .itxn import InnerTxnBuilder, InnerTxn
+from .itxn import InnerTxnBuilder, InnerTxn, InnerTxnAction
 
 # meta
 from .array import Array
@@ -42,6 +45,7 @@ from .unaryexpr import (
     Balance,
     MinBalance,
     BytesNot,
+    BytesSqrt,
     BytesZero,
     Log,
 )
@@ -88,7 +92,8 @@ from .binaryexpr import (
 )
 
 # ternary ops
-from .ternaryexpr import Ed25519Verify, Substring, Extract, SetBit, SetByte
+from .ternaryexpr import Divw, Ed25519Verify, SetBit, SetByte
+from .substring import Substring, Extract, Suffix
 
 # more ops
 from .naryexpr import NaryExpr, And, Or, Concat
@@ -106,6 +111,7 @@ from .subroutine import (
     SubroutineDefinition,
     SubroutineDeclaration,
     SubroutineCall,
+    SubroutineFnWrapper,
 )
 from .while_ import While
 from .for_ import For
@@ -117,6 +123,7 @@ from .continue_ import Continue
 from .scratch import ScratchSlot, ScratchLoad, ScratchStore, ScratchStackStore
 from .scratchvar import ScratchVar
 from .maybe import MaybeValue
+from .multi import MultiValue
 
 __all__ = [
     "Expr",
@@ -125,6 +132,7 @@ __all__ = [
     "Bytes",
     "Int",
     "EnumInt",
+    "MethodSignature",
     "Arg",
     "TxnType",
     "TxnField",
@@ -147,8 +155,14 @@ __all__ = [
     "AppParam",
     "AssetHolding",
     "AssetParam",
+    "AccountParam",
     "InnerTxnBuilder",
     "InnerTxn",
+    "InnerTxnAction",
+    "Gitxn",
+    "GitxnExpr",
+    "GitxnaExpr",
+    "InnerTxnGroup",
     "Array",
     "Tmpl",
     "Nonce",
@@ -173,6 +187,7 @@ __all__ = [
     "Div",
     "Mod",
     "Exp",
+    "Divw",
     "BitwiseAnd",
     "BitwiseOr",
     "BitwiseXor",
@@ -189,6 +204,7 @@ __all__ = [
     "Ed25519Verify",
     "Substring",
     "Extract",
+    "Suffix",
     "SetBit",
     "SetByte",
     "NaryExpr",
@@ -208,12 +224,14 @@ __all__ = [
     "SubroutineDefinition",
     "SubroutineDeclaration",
     "SubroutineCall",
+    "SubroutineFnWrapper",
     "ScratchSlot",
     "ScratchLoad",
     "ScratchStore",
     "ScratchStackStore",
     "ScratchVar",
     "MaybeValue",
+    "MultiValue",
     "BytesAdd",
     "BytesMinus",
     "BytesDiv",
@@ -229,6 +247,7 @@ __all__ = [
     "BytesGt",
     "BytesGe",
     "BytesNot",
+    "BytesSqrt",
     "BytesZero",
     "ExtractUint16",
     "ExtractUint32",
