@@ -134,7 +134,7 @@ def test_compile_version_invalid():
         compileTeal(expr, Mode.Signature, version=1)  # too small
 
     with pytest.raises(TealInputError):
-        compileTeal(expr, Mode.Signature, version=6)  # too large
+        compileTeal(expr, Mode.Signature, version=7)  # too large
 
     with pytest.raises(TealInputError):
         compileTeal(expr, Mode.Signature, version=2.0)  # decimal
@@ -195,6 +195,17 @@ return
     assert actual == expected
 
 
+def test_compile_version_6():
+    expr = Int(1)
+    expected = """
+#pragma version 6
+int 1
+return
+""".strip()
+    actual = compileTeal(expr, Mode.Signature, version=6)
+    assert actual == expected
+
+
 def test_slot_load_before_store():
 
     program = AssetHolding.balance(Int(0), Int(0)).value()
@@ -408,8 +419,7 @@ def test_compile_for():
         ]
     )
 
-    expected = """
-    #pragma version 4
+    expected = """#pragma version 4
 int 0
 store 0
 main_l1:
@@ -455,8 +465,7 @@ return
         ]
     )
 
-    expected = """
-        #pragma version 4
+    expected = """#pragma version 4
 int 0
 store 0
 main_l1:
@@ -491,7 +500,7 @@ b main_l3
 main_l6:
 int 1
 return
-        """.strip()
+    """.strip()
     actual = compileTeal(program, Mode.Application, version=4, assembleConstants=False)
     assert expected == actual
 
@@ -817,11 +826,13 @@ global CreatorAddress
 ==
 bz main_l2
 txna ApplicationArgs 0
-callsub sub0
+callsub storeValue_0
 main_l2:
 int 1
 return
-sub0: // storeValue
+
+// storeValue
+storeValue_0:
 store 0
 byte "key"
 load 0
@@ -857,7 +868,7 @@ global CreatorAddress
 ==
 bnz main_l3
 main_l1:
-callsub sub1
+callsub getValue_1
 byte "fail"
 ==
 bz main_l4
@@ -865,18 +876,22 @@ int 0
 return
 main_l3:
 txna ApplicationArgs 0
-callsub sub0
+callsub storeValue_0
 b main_l1
 main_l4:
 int 1
 return
-sub0: // storeValue
+
+// storeValue
+storeValue_0:
 store 0
 byte "key"
 load 0
 app_global_put
 retsub
-sub1: // getValue
+
+// getValue
+getValue_1:
 byte "key"
 app_global_get
 retsub
@@ -904,11 +919,13 @@ int 3
 int 4
 int 5
 int 6
-callsub sub0
+callsub calculateSum_0
 int 21
 ==
 return
-sub0: // calculateSum
+
+// calculateSum
+calculateSum_0:
 store 5
 store 4
 store 3
@@ -947,35 +964,37 @@ def test_compile_subroutine_recursive():
 
     expected = """#pragma version 4
 int 6
-callsub sub0
+callsub isEven_0
 return
-sub0: // isEven
+
+// isEven
+isEven_0:
 store 0
 load 0
 int 0
 ==
-bnz sub0_l4
+bnz isEven_0_l4
 load 0
 int 1
 ==
-bnz sub0_l3
+bnz isEven_0_l3
 load 0
 int 2
 -
 load 0
 dig 1
-callsub sub0
+callsub isEven_0
 swap
 store 0
 swap
 pop
-b sub0_l5
-sub0_l3:
+b isEven_0_l5
+isEven_0_l3:
 int 0
-b sub0_l5
-sub0_l4:
+b isEven_0_l5
+isEven_0_l4:
 int 1
-sub0_l5:
+isEven_0_l5:
 retsub
     """.strip()
     actual = compileTeal(program, Mode.Application, version=4, assembleConstants=False)
@@ -997,33 +1016,35 @@ def test_compile_subroutine_recursive_5():
 
     expected = """#pragma version 5
 int 6
-callsub sub0
+callsub isEven_0
 return
-sub0: // isEven
+
+// isEven
+isEven_0:
 store 0
 load 0
 int 0
 ==
-bnz sub0_l4
+bnz isEven_0_l4
 load 0
 int 1
 ==
-bnz sub0_l3
+bnz isEven_0_l3
 load 0
 int 2
 -
 load 0
 swap
-callsub sub0
+callsub isEven_0
 swap
 store 0
-b sub0_l5
-sub0_l3:
+b isEven_0_l5
+isEven_0_l3:
 int 0
-b sub0_l5
-sub0_l4:
+b isEven_0_l5
+isEven_0_l4:
 int 1
-sub0_l5:
+isEven_0_l5:
 retsub
     """.strip()
     actual = compileTeal(program, Mode.Application, version=5, assembleConstants=False)
@@ -1044,15 +1065,17 @@ def test_compile_subroutine_recursive_multiple_args():
     expected = """#pragma version 4
 int 3
 int 5
-callsub sub0
+callsub multiplyByAdding_0
 return
-sub0: // multiplyByAdding
+
+// multiplyByAdding
+multiplyByAdding_0:
 store 1
 store 0
 load 0
 int 0
 ==
-bnz sub0_l2
+bnz multiplyByAdding_0_l2
 load 1
 load 0
 int 1
@@ -1062,7 +1085,7 @@ load 0
 load 1
 dig 3
 dig 3
-callsub sub0
+callsub multiplyByAdding_0
 store 0
 store 1
 load 0
@@ -1074,7 +1097,7 @@ swap
 pop
 +
 retsub
-sub0_l2:
+multiplyByAdding_0_l2:
 int 0
 retsub
     """.strip()
@@ -1096,15 +1119,17 @@ def test_compile_subroutine_recursive_multiple_args_5():
     expected = """#pragma version 5
 int 3
 int 5
-callsub sub0
+callsub multiplyByAdding_0
 return
-sub0: // multiplyByAdding
+
+// multiplyByAdding
+multiplyByAdding_0:
 store 1
 store 0
 load 0
 int 0
 ==
-bnz sub0_l2
+bnz multiplyByAdding_0_l2
 load 1
 load 0
 int 1
@@ -1114,13 +1139,13 @@ load 0
 load 1
 uncover 3
 uncover 3
-callsub sub0
+callsub multiplyByAdding_0
 cover 2
 store 1
 store 0
 +
 retsub
-sub0_l2:
+multiplyByAdding_0_l2:
 int 0
 retsub
     """.strip()
@@ -1141,51 +1166,55 @@ def test_compile_subroutine_mutually_recursive():
 
     expected = """#pragma version 4
 int 6
-callsub sub0
+callsub isEven_0
 return
-sub0: // isEven
+
+// isEven
+isEven_0:
 store 0
 load 0
 int 0
 ==
-bnz sub0_l2
+bnz isEven_0_l2
 load 0
 int 1
 -
 load 0
 dig 1
-callsub sub1
+callsub isOdd_1
 swap
 store 0
 swap
 pop
 !
-b sub0_l3
-sub0_l2:
+b isEven_0_l3
+isEven_0_l2:
 int 1
-sub0_l3:
+isEven_0_l3:
 retsub
-sub1: // isOdd
+
+// isOdd
+isOdd_1:
 store 1
 load 1
 int 0
 ==
-bnz sub1_l2
+bnz isOdd_1_l2
 load 1
 int 1
 -
 load 1
 dig 1
-callsub sub0
+callsub isEven_0
 swap
 store 1
 swap
 pop
 !
-b sub1_l3
-sub1_l2:
+b isOdd_1_l3
+isOdd_1_l2:
 int 0
-sub1_l3:
+isOdd_1_l3:
 retsub
     """.strip()
     actual = compileTeal(program, Mode.Application, version=4, assembleConstants=False)
@@ -1205,47 +1234,51 @@ def test_compile_subroutine_mutually_recursive_5():
 
     expected = """#pragma version 5
 int 6
-callsub sub0
+callsub isEven_0
 return
-sub0: // isEven
+
+// isEven
+isEven_0:
 store 0
 load 0
 int 0
 ==
-bnz sub0_l2
+bnz isEven_0_l2
 load 0
 int 1
 -
 load 0
 swap
-callsub sub1
+callsub isOdd_1
 swap
 store 0
 !
-b sub0_l3
-sub0_l2:
+b isEven_0_l3
+isEven_0_l2:
 int 1
-sub0_l3:
+isEven_0_l3:
 retsub
-sub1: // isOdd
+
+// isOdd
+isOdd_1:
 store 1
 load 1
 int 0
 ==
-bnz sub1_l2
+bnz isOdd_1_l2
 load 1
 int 1
 -
 load 1
 swap
-callsub sub0
+callsub isEven_0
 swap
 store 1
 !
-b sub1_l3
-sub1_l2:
+b isOdd_1_l3
+isOdd_1_l2:
 int 0
-sub1_l3:
+isOdd_1_l3:
 retsub
     """.strip()
     actual = compileTeal(program, Mode.Application, version=5, assembleConstants=False)
@@ -1264,18 +1297,20 @@ def test_compile_loop_in_subroutine():
 
     expected = """#pragma version 4
 byte "value"
-callsub sub0
+callsub setState_0
 int 1
 return
-sub0: // setState
+
+// setState
+setState_0:
 store 0
 int 0
 store 1
-sub0_l1:
+setState_0_l1:
 load 1
 int 10
 <
-bz sub0_l3
+bz setState_0_l3
 load 1
 itob
 load 0
@@ -1284,8 +1319,28 @@ load 1
 int 1
 +
 store 1
-b sub0_l1
-sub0_l3:
+b setState_0_l1
+setState_0_l3:
+retsub
+    """.strip()
+    actual = compileTeal(program, Mode.Application, version=4, assembleConstants=False)
+    assert actual == expected
+
+
+def test_compile_subroutine_invalid_name():
+    def tmp() -> Expr:
+        return Int(1)
+
+    tmp.__name__ = "invalid-;)"
+
+    program = Subroutine(TealType.uint64)(tmp)()
+    expected = """#pragma version 4
+callsub invalid_0
+return
+
+// invalid-;)
+invalid_0:
+int 1
 retsub
     """.strip()
     actual = compileTeal(program, Mode.Application, version=4, assembleConstants=False)
@@ -1326,11 +1381,13 @@ concat
 intc_0 // 1
 intc_0 // 1
 pushint 3 // 3
-callsub sub0
+callsub storeValue_0
 main_l2:
 intc_0 // 1
 return
-sub0: // storeValue
+
+// storeValue
+storeValue_0:
 store 3
 store 2
 store 1
